# `BioClients.opentargets`

## Open Targets

OpenTargets REST API client, using the Python client package
`opentargets`.

```
pip3 install opentargets
```

* <https://www.targetvalidation.org/documentation/api/>
* <http://opentargets.readthedocs.io/>
* <https://docs.targetvalidation.org/programmatic-access/python-client>
* <https://docs.targetvalidation.org/programmatic-access/rest-api>
* <https://docs.targetvalidation.org/data-sources/genetic-associations>
* <https://platform-api.opentargets.io/v3/platform>
* <https://platform-api.opentargets.io/v3/platform/docs/swagger-ui>
* <https://pypi.org/project/opentargets/>
